┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/dolphinviewactionhandler.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/dolphinviewactionhandler.h')
-rw-r--r--src/dolphinviewactionhandler.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/dolphinviewactionhandler.h b/src/dolphinviewactionhandler.h
index 4186a479f..0bdb88764 100644
--- a/src/dolphinviewactionhandler.h
+++ b/src/dolphinviewactionhandler.h
@@ -219,11 +219,12 @@ private:
* This is called only once (by the constructor)
*/
void createActions();
+
/**
* Creates an action menu with all the "show additional information" actions in it.
* Helper method for createActions();
*/
- KActionMenu* createAdditionalInformationActionMenu();
+ QActionGroup* createAdditionalInformationActionGroup();
/**
* Creates an action group with all the "sort by" actions in it.
@@ -219,11 +219,12 @@ private:
/**
- * Creates an action menu with all the "show additional information" actions in it.
+ * Creates an action group with all the "show additional information" actions in it.
* Helper method for createActions();
*/